@@ -6,6 +6,9 @@ suppressPackageStartupMessages(require(tangram.pipe))
 suppressPackageStartupMessages(require(knitr))
 suppressPackageStartupMessages(require(kableExtra))
 
+## ---- echo = FALSE------------------------------------------------------------
+set.seed(04082022)
+
 ## -----------------------------------------------------------------------------
 iris$color <- sample(c("Blue", "Purple"), size=150, replace=TRUE)
 iris$Stem.Size <- sample(c("Small", "Medium", "Medium", "Large"), size=150, replace=TRUE)
@@ -22,153 +25,110 @@ tbl1 <- tbl_start(data=iris,
                   missing=FALSE, 
                   overall=TRUE, 
                   comparison=FALSE,
+                  digits = 2,
                   default_num_summary = num_default,
                   default_cat_summary = cat_default,
                   default_binary_summary = binary_default)
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
-#    num_row(row_var="Sepal.Length", rowlabel="Sepal Length") %>%
-#    tbl_out() %>%
-#    print()
-#  tbl1 %>%
-#    tangram_styling() %>%
-#    kable(escape=F, align="l") %>%
-#    trimws %>%
-#    kable_styling(c("striped","bordered"))
-
-## ---- echo=FALSE--------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>% 
   num_row(row_var="Sepal.Length", rowlabel="Sepal Length") %>%
   tbl_out()
-tbl1[[11]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
   kable_styling(c("striped","bordered"))
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
-#    num_row(row_var="Sepal.Length", rowlabel="Sepal Length", digits=4) %>%
-#    tbl_out() %>%
-#    print()
-#  tbl1 %>%
-#    tangram_styling() %>%
-#    kable(escape=F, align="l") %>%
-#    trimws %>%
-#    kable_styling(c("striped","bordered"))
-
-## ---- echo=FALSE--------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>% 
   num_row(row_var="Sepal.Length", rowlabel="Sepal Length", digits=4) %>%
   tbl_out()
-tbl1[[11]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
   kable_styling(c("striped","bordered"))
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
-#    num_row(row_var="Sepal.Length", rowlabel="Sepal Length", missing=TRUE) %>%
-#    tbl_out() %>%
-#    print()
-#  tbl1 %>%
-#    tangram_styling() %>%
-#    kable(escape=F, align="l") %>%
-#    trimws %>%
-#    kable_styling(c("striped","bordered"))
-
-## ---- echo=FALSE--------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>% 
   num_row(row_var="Sepal.Length", rowlabel="Sepal Length", missing=TRUE) %>%
   tbl_out()
-tbl1[[11]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
   kable_styling(c("striped","bordered"))
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
 #    num_row(row_var="Sepal.Length", rowlabel="Sepal Length", comparison=num_diff) %>%
-#    tbl_out() %>%
-#    print()
+#    tbl_out()
 #  tbl1 %>%
 #    tangram_styling() %>%
 #    kable(escape=F, align="l") %>%
 #    trimws %>%
 #    kable_styling(c("striped","bordered"))
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ---- echo = FALSE------------------------------------------------------------
 tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>% 
   num_row(row_var="Sepal.Length", rowlabel="Sepal Length", comparison=num_diff) %>%
   tbl_out()
-tbl1[[11]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
   kable_styling(c("striped","bordered")) %>%
   column_spec(c(7:9), width_min = "1.5in")
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
-#    cat_row("Stem.Size", rowlabel="Stem Size") %>%
-#    tbl_out() %>%
-#    print()
-#  tbl1 %>%
-#    tangram_styling() %>%
-#    kable(escape=F, align="l") %>%
-#    trimws %>%
-#    kable_styling(c("striped","bordered"))
-
-## ---- echo=FALSE--------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>% 
   cat_row("Stem.Size", rowlabel="Stem Size") %>%
   tbl_out()
-tbl1[[11]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
   kable_styling(c("striped","bordered"))
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
-#    cat_row("Stem.Size", rowlabel="Stem Size", missing=TRUE) %>%
-#    tbl_out() %>%
-#    print()
-#  tbl1 %>%
-#    tangram_styling() %>%
-#    kable(escape=F, align="l") %>%
-#    trimws %>%
-#    kable_styling(c("striped","bordered"))
-
-## ---- echo=FALSE--------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>% 
   cat_row("Stem.Size", rowlabel="Stem Size", missing=TRUE) %>%
   tbl_out()
-tbl1[[11]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
   kable_styling(c("striped","bordered"))
 
-## ---- eval=FALSE--------------------------------------------------------------
+## -----------------------------------------------------------------------------
+tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>% 
+  cat_row("Stem.Size", rowlabel="Stem Size (Ascending by versicolor)", missing=TRUE, 
+          ordering = "ascending", sortcol = "versicolor") %>%
+  cat_row("Stem.Size", rowlabel="Stem Size (Descending by overall count)", missing=TRUE, 
+          ordering = "descending") %>%
+  tbl_out()
+tbl1 %>% 
+  tangram_styling() %>% 
+  kable(escape=F, align="l") %>% 
+  trimws %>% 
+  kable_styling(c("striped","bordered"))
+
+## ---- eval = FALSE------------------------------------------------------------
 #  tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
 #    cat_row("Stem.Size", rowlabel="Stem Size", comparison=cat_comp_default) %>%
-#    tbl_out() %>%
-#    print()
+#    tbl_out()
 #  tbl1 %>%
 #    tangram_styling() %>%
 #    kable(escape=F, align="l") %>%
 #    trimws %>%
 #    kable_styling(c("striped","bordered"))
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ---- echo = FALSE------------------------------------------------------------
 tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>% 
   cat_row("Stem.Size", rowlabel="Stem Size", comparison=cat_comp_default) %>%
   tbl_out()
-tbl1[[11]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
@@ -176,155 +136,111 @@ tbl1[[11]] %>%
   column_spec(c(2:6), width_min = "1.1in") %>%
   column_spec(7, width_min = "1.5in")
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
-#    binary_row("color") %>%
-#    tbl_out() %>%
-#    print()
-#  tbl1 %>%
-#    tangram_styling() %>%
-#    kable(escape=F, align="l") %>%
-#    trimws %>%
-#    kable_styling(c("striped","bordered"))
-
-## ---- echo=FALSE--------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>% 
-  binary_row("color") %>%
+  binary_row("color", rowlabel = "Color") %>%
   tbl_out()
-tbl1[[11]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
   kable_styling(c("striped","bordered"))
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
-#    binary_row("color", reference="Purple") %>%
-#    tbl_out() %>%
-#    print()
-#  tbl1 %>%
-#    tangram_styling() %>%
-#    kable(escape=F, align="l") %>%
-#    trimws %>%
-#    kable_styling(c("striped","bordered"))
-
-## ---- echo=FALSE--------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>% 
-  binary_row("color", reference="Purple") %>%
+  binary_row("color", rowlabel = "Color", reference="Purple") %>%
   tbl_out()
-tbl1[[11]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
   kable_styling(c("striped","bordered"))
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
-#    binary_row("color", rowlabel = "Color", compact = FALSE) %>%
-#    tbl_out() %>%
-#    print()
-#  tbl1 %>%
-#    tangram_styling() %>%
-#    kable(escape=F, align="l") %>%
-#    trimws %>%
-#    kable_styling(c("striped","bordered"))
-
-## ---- echo=FALSE--------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>% 
   binary_row("color", rowlabel = "Color", compact = FALSE) %>%
   tbl_out()
-tbl1[[11]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
   kable_styling(c("striped","bordered"))
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
 #    binary_row("color", comparison=binary_diff) %>%
-#    tbl_out() %>%
-#    print()
+#    tbl_out()
 #  tbl1 %>%
 #    tangram_styling() %>%
 #    kable(escape=F, align="l") %>%
 #    trimws %>%
 #    kable_styling(c("striped","bordered"))
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ---- echo = FALSE------------------------------------------------------------
 tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>% 
   binary_row("color", comparison=binary_diff) %>%
   tbl_out()
-tbl1[[11]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
   kable_styling(c("striped","bordered")) %>%
+  column_spec(1, width_min = "1in") %>%
   column_spec(c(2:6), width_min = "1.1in") %>%
   column_spec(7, width_min = "1.75in") %>%
   column_spec(c(8:9), width_min = "1.5in")
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
 #    binary_row("color", comparison=binary_or) %>%
-#    tbl_out() %>%
-#    print()
+#    tbl_out()
 #  tbl1 %>%
 #    tangram_styling() %>%
 #    kable(escape=F, align="l") %>%
 #    trimws %>%
 #    kable_styling(c("striped","bordered"))
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ---- echo = FALSE------------------------------------------------------------
 tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>% 
   binary_row("color", comparison=binary_or) %>%
   tbl_out()
-tbl1[[11]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
   kable_styling(c("striped","bordered")) %>%
+  column_spec(1, width_min = "1in") %>%
   column_spec(c(2:7), width_min = "1.1in") %>%
   column_spec(c(8:9), width_min = "1.25in")
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
 #    binary_row("color", comparison=binary_rr) %>%
-#    tbl_out() %>%
-#    print()
+#    tbl_out()
 #  tbl1 %>%
 #    tangram_styling() %>%
 #    kable(escape=F, align="l") %>%
 #    trimws %>%
 #    kable_styling(c("striped","bordered"))
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ---- echo = FALSE------------------------------------------------------------
 tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>% 
   binary_row("color", comparison=binary_rr) %>%
   tbl_out()
-tbl1[[11]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
   kable_styling(c("striped","bordered")) %>%
+  column_spec(1, width_min = "1in") %>%
   column_spec(c(2:7), width_min = "1.1in") %>%
   column_spec(c(8:9), width_min = "1.25in")
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
-#    n_row() %>%
-#    tbl_out() %>%
-#    print()
-#  tbl1 %>%
-#    tangram_styling() %>%
-#    kable(escape=F, align="l") %>%
-#    trimws %>%
-#    kable_styling(c("striped","bordered"))
-
-## ---- echo=FALSE--------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tbl1 <- tbl_start(data=iris, col_var="Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>% 
   n_row() %>%
   tbl_out()
-tbl1[[11]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
@@ -353,9 +269,8 @@ tbl1[[11]] %>%
 #    num_row("Petal.Width", rowlabel="Petal Width", summary = num_mean_sd, missing=TRUE) %>%
 #    cat_row("Stem.Size", rowlabel="Stem Size", missing=TRUE) %>%
 #    empty_row("<i>No rowlabels, indent 3 spaces, odds ratio as test</i>") %>%
-#    binary_row("color", comparison=binary_or, indent=3) %>%
-#    tbl_out() %>%
-#    print()
+#    binary_row("color", missing = TRUE, comparison=binary_or, indent=3) %>%
+#    tbl_out()
 #  tbl1 %>%
 #    tangram_styling() %>%
 #    kable(escape=F, align="l") %>%
@@ -382,9 +297,9 @@ tbl1 <- tbl_start(
   num_row("Petal.Width", rowlabel="Petal Width", summary = num_mean_sd, missing=TRUE) %>%
   cat_row("Stem.Size", rowlabel="Stem Size", missing=TRUE) %>%
   empty_row("<i>No rowlabels, indent 3 spaces, odds ratio as test</i>") %>%
-  binary_row("color", comparison=binary_or, indent=3) %>%
+  binary_row("color", missing = TRUE, comparison=binary_or, indent=3) %>%
   tbl_out()
-tbl1[[21]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
@@ -393,24 +308,12 @@ tbl1[[21]] %>%
   column_spec(c(2:6), width_min = "1.3in") %>%
   column_spec(c(7:9), width_min = "1.5in")
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  tbl1 <- tbl_start(iris, NULL, missing=FALSE, overall=TRUE, comparison=FALSE) %>%
-#    n_row() %>%
-#    num_row("Sepal.Length", rowlabel="Sepal Length") %>%
-#    tbl_out() %>%
-#    print()
-#  tbl1 %>%
-#    tangram_styling() %>%
-#    kable(escape=F, align="l") %>%
-#    trimws %>%
-#    kable_styling(c("striped","bordered"))
-
-## ---- echo=FALSE--------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tbl1 <- tbl_start(iris, NULL, missing=FALSE, overall=TRUE, comparison=FALSE) %>%
   n_row() %>%
   num_row("Sepal.Length", rowlabel="Sepal Length") %>%
   tbl_out()
-tbl1[[12]] %>% 
+tbl1 %>% 
   tangram_styling() %>%
   kable(escape=F, align="l") %>% 
   trimws %>% 
@@ -420,22 +323,7 @@ tbl1[[12]] %>%
 sepaldat <- iris %>% select(-c(Petal.Length, Petal.Width))
 petaldat <- iris %>% select(-c(Sepal.Length, Sepal.Width))
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  tbl1 <- tbl_start(sepaldat, "Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
-#    num_row("Sepal.Length", rowlabel="Sepal Length") %>%
-#    num_row("Sepal.Width", rowlabel="Sepal Width") %>%
-#    empty_row(header="Switch to Petal Dataset") %>%
-#    num_row(row_var="Petal.Length", col_var="Species", rowlabel="Petal Length", newdata=petaldat) %>%
-#    num_row(row_var="Petal.Width", col_var="Species", rowlabel="Petal Width", newdata=petaldat) %>%
-#    tbl_out() %>%
-#    print()
-#  tbl1 %>%
-#    tangram_styling() %>%
-#    kable(escape=F, align="l") %>%
-#    trimws %>%
-#    kable_styling(c("striped","bordered"))
-
-## ---- echo=FALSE--------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tbl1 <- tbl_start(sepaldat, "Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
   num_row("Sepal.Length", rowlabel="Sepal Length") %>%
   num_row("Sepal.Width", rowlabel="Sepal Width") %>%
@@ -443,7 +331,7 @@ tbl1 <- tbl_start(sepaldat, "Species", missing=FALSE, overall=TRUE, comparison=F
   num_row(row_var="Petal.Length", col_var="Species", newdata=petaldat, rowlabel="Petal Length") %>%
   num_row(row_var="Petal.Width", col_var="Species", newdata=petaldat, rowlabel="Petal Width") %>%
   tbl_out()
-tbl1[[15]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>%
   trimws %>%
@@ -453,29 +341,7 @@ tbl1[[15]] %>%
 petal.small <- iris %>% filter(Petal.Length <= 4.3)
 petal.large <- iris %>% filter(Petal.Length > 4.3)
 
-## ---- eval=FALSE--------------------------------------------------------------
-#  tbl1 <- tbl_start(iris, "Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
-#    empty_row(header="All Data") %>%
-#    n_row() %>%
-#    num_row("Sepal.Length", rowlabel="     Sepal Length") %>%
-#    num_row("Sepal.Width", rowlabel="     Sepal Width") %>%
-#    empty_row(header="Petal Length less than 4.3") %>%
-#    n_row(newdata=petal.small) %>%
-#    num_row("Sepal.Length", rowlabel="     Sepal Length", col_var="Species", newdata=petal.small) %>%
-#    num_row("Sepal.Width", rowlabel="     Sepal Width", col_var="Species", newdata=petal.small) %>%
-#    empty_row(header="Petal Length greater than 4.3") %>%
-#    n_row(newdata=petal.large) %>%
-#    num_row("Sepal.Length", rowlabel="     Sepal Length", col_var="Species", newdata=petal.large) %>%
-#    num_row("Sepal.Width", rowlabel="     Sepal Width", col_var="Species", newdata=petal.large) %>%
-#    tbl_out() %>%
-#    print()
-#  tbl1 %>%
-#    tangram_styling() %>%
-#    kable(escape=F, align="l") %>%
-#    trimws %>%
-#    kable_styling(c("striped","bordered"))
-
-## ---- echo=FALSE--------------------------------------------------------------
+## -----------------------------------------------------------------------------
 tbl1 <- tbl_start(iris, "Species", missing=FALSE, overall=TRUE, comparison=FALSE) %>%
   empty_row(header="All Data") %>%
   n_row() %>%
@@ -490,9 +356,44 @@ tbl1 <- tbl_start(iris, "Species", missing=FALSE, overall=TRUE, comparison=FALSE
   num_row("Sepal.Length", rowlabel="     Sepal Length", col_var="Species", newdata=petal.large) %>%
   num_row("Sepal.Width", rowlabel="     Sepal Width", col_var="Species", newdata=petal.large) %>%
   tbl_out()
-tbl1[[22]] %>% 
+tbl1 %>% 
   tangram_styling() %>% 
   kable(escape=F, align="l") %>% 
   trimws %>% 
   kable_styling(c("striped","bordered"))
 
+## ---- eval = FALSE------------------------------------------------------------
+#  tbl1 <- tbl_start(iris, "Species", missing=TRUE, overall=TRUE, comparison=TRUE,
+#                    default_num_summary = num_minmax,
+#                    default_cat_summary = cat_pct,
+#                    default_binary_summary = binary_jama) %>%
+#    n_row() %>%
+#    num_row("Sepal.Length", rowlabel="Sepal Length") %>%
+#    cat_row("Stem.Size", rowlabel="Stem Size") %>%
+#    binary_row("color", rowlabel="Color") %>%
+#    tbl_out()
+#  tbl1 %>%
+#    tangram_styling() %>%
+#    kable(escape=F, align="l", caption = "Example Summary table", format = "html") %>%
+#    trimws %>%
+#    kable_styling(c("striped","bordered"), font_size = 12)
+
+## ---- echo = FALSE------------------------------------------------------------
+tbl1 <- tbl_start(iris, "Species", missing=TRUE, overall=TRUE, comparison=TRUE, 
+                  default_num_summary = num_minmax,
+                  default_cat_summary = cat_pct,
+                  default_binary_summary = binary_jama) %>%
+  n_row() %>%
+  num_row("Sepal.Length", rowlabel="Sepal Length") %>%
+  cat_row("Stem.Size", rowlabel="Stem Size") %>%
+  binary_row("color", rowlabel="Color") %>%
+  tbl_out()
+tbl1 %>% 
+  tangram_styling() %>% 
+  kable(escape=F, align="l", caption = "Example Summary table", format = "html") %>% 
+  trimws %>% 
+  kable_styling(c("striped","bordered"), font_size = 12) %>%
+  column_spec(1, width_min = "1.5in") %>%
+  column_spec(c(2:6), width_min = "1.3in") %>%
+  column_spec(c(7:9), width_min = "1.5in")
+
